@@ -13,5 +13,6 @@ def is_moderator(user: model.User, comment, thread) -> bool:
     checker = tk.config.get(
         const.CONFIG_MODERATOR_CHECKER, const.DEFAULT_MODERATOR_CHECKER
     )
-    func = import_string(checker, silent=True) or is_moderator
+
+    func = import_string(checker, silent=True) or comments_is_moderator
     return func(user, comment, thread)
